@@ -326,7 +326,12 @@ vector xhypot (vector v1, vector v2) {
   vector res (len);
   for (j = i = n = 0; n < len; n++) {
     res (n) = xhypot (v1 (i), v2 (j));
-    if (++i >= len1) i = 0; if (++j >= len2) j = 0;
+    if (++i >= len1) {
+        i = 0;
+    }
+    if (++j >= len2) {
+        j = 0;
+    }
   }
   return res;
 }
@@ -452,7 +457,12 @@ vector pow (vector v1, vector v2) {
   vector res (len);
   for (j = i = n = 0; n < len; n++) {
     res (n) = pow (v1 (i), v2 (j));
-    if (++i >= len1) i = 0; if (++j >= len2) j = 0;
+    if (++i >= len1) {
+        i = 0;
+    }
+    if (++j >= len2) {
+        j = 0;
+    }
   }
   return res;
 }
@@ -906,7 +916,12 @@ vector operator%(vector v1, vector v2) {
   vector res (len);
   for (j = i = n = 0; n < len; n++) {
     res (n) = v1 (i) % v2 (j);
-    if (++i >= len1) i = 0;  if (++j >= len2) j = 0;
+    if (++i >= len1) {
+        i = 0;
+    }
+    if (++j >= len2) {
+        j = 0;
+    }
   }
   return res;
 }
@@ -1173,7 +1188,12 @@ vector polar (vector a, vector p) {
   vector res (len);
   for (j = i = n = 0; n < len; n++) {
     res (n) = qucs::polar (a (i), p (j));
-    if (++i >= len1) i = 0;  if (++j >= len2) j = 0;
+    if (++i >= len1) {
+        i = 0;
+    }
+    if (++j >= len2) {
+        j = 0;
+    }
   }
   return res;
 }
@@ -1204,7 +1224,12 @@ vector atan2 (vector y, vector x) {
   vector res (len);
   for (j = i = n = 0; n < len; n++) {
     res (n) = atan2 (y (i), x (j));
-    if (++i >= len1) i = 0; if (++j >= len2) j = 0;
+    if (++i >= len1) {
+        i = 0;
+    }
+    if (++j >= len2) {
+        j = 0;
+    }
   }
   return res;
 }
