@@ -84,22 +84,27 @@ void Component::Bounding(int &_x1, int &_y1, int &_x2, int &_y2) {
 int Component::textSize(int &_dx, int &_dy) {
     // get size of text using the screen-compatible metric
     QFontMetrics metrics(QucsSettings.font, 0);
-
-    int tmp, count = 0;
+    int count = 0;
     _dx = _dy = 0;
+
     if (showName) {
         _dx = metrics.boundingRect(Name).width();
         _dy = metrics.height();
         count++;
     }
-    for (Property *pp = Props.first(); pp != 0; pp = Props.next())
-        if (pp->display) {
-            // get width of text
-            tmp = metrics.boundingRect(pp->Name + "=" + pp->Value).width();
-            if (tmp > _dx) _dx = tmp;
-            _dy += metrics.height();
-            count++;
+
+    constexpr int flags = 0b00000000;
+    for (Property* p : Props) {
+        if (!(p->display)) continue;
+
+        // Update overall width if text of the current property is wider
+        auto w = metrics.size(flags, p->Name + "=" + p->Value).width();
+        if (w > _dx) {
+            _dx = w;
         }
+        _dy += metrics.height();
+        count++;
+    }
     return count;
 }
 
@@ -424,37 +429,42 @@ void Component::paintIcon(QPixmap *pixmap)
 // Paints the component when moved with the mouse.
 void Component::paintScheme(Schematic *p) {
     // qDebug() << "paintScheme" << Model;
-    if (Model.at(0) == '.') {   // is simulation component (dc, ac, ...)
-        int a, b, xb, yb;
-        QFont newFont = p->font();
+    if (Model.at(0) == '.' || isEquation) {   // is simulation component (dc, ac, ...) + Equations
+//        int a, b, xb, yb;
+//        QFont newFont = p->font();
+//
+//        float Scale =
+//                ((Schematic *) QucsMain->DocumentTab->currentWidget())->Scale;
+//        newFont.setPointSizeF(float(Scale) * QucsSettings.largeFontSize);
+//        newFont.setWeight(QFont::DemiBold);
+//        // here the font metric is already the screen metric, since the font
+//        // is the current font the painter is using
+//        QFontMetrics metrics(newFont);
+//
+//        a = b = 0;
+//        QSize r;
+//        for (Text *pt: Texts) {
+//            r = metrics.size(0, pt->s);
+//            b += r.height();
+//            if (a < r.width()) a = r.width();
+//        }
+//        xb = a + int(12.0 * Scale);
+//        yb = b + int(10.0 * Scale);
+//        x2 = x1 + 25 + int(float(a) / Scale);
+//        y2 = y1 + 23 + int(float(b) / Scale);
+//        if (ty < y2 + 1) if (ty > y1 - r.height()) ty = y2 + 1;
+//
+//        p->PostPaintEvent(_Rect, cx - 6, cy - 5, xb, yb);
+//        p->PostPaintEvent(_Line, cx - 1, cy + yb, cx - 6, cy + yb - 5);
+//        p->PostPaintEvent(_Line, cx + xb - 2, cy + yb, cx - 1, cy + yb);
+//        p->PostPaintEvent(_Line, cx + xb - 2, cy + yb, cx + xb - 6, cy + yb - 5);
+//        p->PostPaintEvent(_Line, cx + xb - 2, cy + yb, cx + xb - 2, cy);
+//        p->PostPaintEvent(_Line, cx + xb - 2, cy, cx + xb - 6, cy - 5);
 
-        float Scale =
-                ((Schematic *) QucsMain->DocumentTab->currentWidget())->Scale;
-        newFont.setPointSizeF(float(Scale) * QucsSettings.largeFontSize);
-        newFont.setWeight(QFont::DemiBold);
-        // here the font metric is already the screen metric, since the font
-        // is the current font the painter is using
-        QFontMetrics metrics(newFont);
+        int _x1, _x2, _y1, _y2;
+        entireBounds(_x1, _y1, _x2, _y2, p->textCorr());
+        p->PostPaintEvent(_Rect, _x1, _y1, _x2 - _x1, _y2 - _y1);
 
-        a = b = 0;
-        QSize r;
-        for (Text *pt: Texts) {
-            r = metrics.size(0, pt->s);
-            b += r.height();
-            if (a < r.width()) a = r.width();
-        }
-        xb = a + int(12.0 * Scale);
-        yb = b + int(10.0 * Scale);
-        x2 = x1 + 25 + int(float(a) / Scale);
-        y2 = y1 + 23 + int(float(b) / Scale);
-        if (ty < y2 + 1) if (ty > y1 - r.height()) ty = y2 + 1;
-
-        p->PostPaintEvent(_Rect, cx - 6, cy - 5, xb, yb);
-        p->PostPaintEvent(_Line, cx - 1, cy + yb, cx - 6, cy + yb - 5);
-        p->PostPaintEvent(_Line, cx + xb - 2, cy + yb, cx - 1, cy + yb);
-        p->PostPaintEvent(_Line, cx + xb - 2, cy + yb, cx + xb - 6, cy + yb - 5);
-        p->PostPaintEvent(_Line, cx + xb - 2, cy + yb, cx + xb - 2, cy);
-        p->PostPaintEvent(_Line, cx + xb - 2, cy, cx + xb - 6, cy - 5);
         return;
     }
 
@@ -463,8 +473,13 @@ void Component::paintScheme(Schematic *p) {
         p->PostPaintEvent(_Line, cx + p1->x1, cy + p1->y1, cx + p1->x2, cy + p1->y2);
 
     // paint all ports
-    for (Port *p2: Ports)
-        if (p2->avail) p->PostPaintEvent(_Ellipse, cx + p2->x - 4, cy + p2->y - 4, 8, 8);
+    for (Port *p2 : Ports)
+      if (p2->avail) {
+        Node *node = p2->Connection;
+        if (!node) {
+          p->PostPaintEvent(_Ellipse, cx + p2->x - 4, cy + p2->y - 4, 8, 8);
+        }
+      }
 
     for (qucs::Arc *p3: Arcs)   // paint all arcs
         p->PostPaintEvent(_Arc, cx + p3->x, cy + p3->y, p3->w, p3->h, p3->angle, p3->arclen);
@@ -590,6 +605,10 @@ void Component::rotate() {
     }
     else ty -= dx;
 
+    if (containingSchematic != nullptr) {
+        containingSchematic->setOnGrid(cx,cy);
+    }
+
     rotated++;  // keep track of what's done
     rotated &= 3;
 }
@@ -1290,7 +1309,7 @@ int Component::analyseLine(const QString &Row, int numProps) {
         return 1;
     } else if (s == "Text") {  // must be last in order to reuse "s" *********
         if (!getIntegers(Row, &i1, &i2, &i3, 0, &i4)) return -1;
-        Color.setNamedColor(Row.section(' ', 4, 4));
+        Color=misc::ColorFromString(Row.section(' ', 4, 4));
         if (!Color.isValid()) return -1;
 
         s = Row.mid(Row.indexOf('"') + 1);    // Text (can contain " !!!)
@@ -1372,8 +1391,7 @@ bool Component::getPen(const QString &s, QPen &Pen, int i) {
     QString n;
 
     n = s.section(' ', i, i);    // color
-    QColor co;
-    co.setNamedColor(n);
+    QColor co = misc::ColorFromString(n);
     Pen.setColor(co);
     if (!Pen.color().isValid()) return false;
 
@@ -1396,8 +1414,7 @@ bool Component::getBrush(const QString &s, QBrush &Brush, int i) {
     QString n;
 
     n = s.section(' ', i, i);    // fill color
-    QColor co;
-    co.setNamedColor(n);
+    QColor co = misc::ColorFromString(n);
     Brush.setColor(co);
     if (!Brush.color().isValid()) return false;
 
