@@ -130,7 +130,7 @@ QString vRect::netlist()
 
   // output all properties
   for(unsigned int i=0; i <= Props.count()-2; i++)
-    if(Props.at(i)->Name != "Symbol")
+    if(Props.at(i)->Name != "U0")
       s += " "+Props.at(i)->Name+"=\""+Props.at(i)->Value+"\"";
 
   return s + '\n';
