@@ -28,6 +28,7 @@
 
 #include <QString>
 #include <QPainter>
+#include <QPainterPath>
 #include <QDebug>
 
 #include <limits.h>
@@ -38,6 +39,8 @@
 
 static double default_Z0=50;
 
+#define IND_SIZE 8
+
 /*!
  * create a marker based on click position and
  * the branch number.
@@ -51,6 +54,7 @@ Marker::Marker(Graph *pg_, int branchNo, int cx_, int cy_) :
   pGraph(pg_),
   Precision(3),
   numMode(0),
+  indicatorMode(indicator_Triangle),
   Z0(default_Z0) // BUG: see declaration.
 {
   Type = isMarker;
@@ -210,8 +214,14 @@ void Marker::createText()
   pz[1] = VarDep[1];
 
   // now actually create text.
+  bool engNotation = pGraph->parentDiagram()->engineeringNotation;
   for(unsigned ii=0; (pD=pGraph->axis(ii)); ++ii) {
-    Text += pD->Var + ": " + QString::number(VarPos[ii],'g',Precision) + "\n";
+    Text += pD->Var + ": ";
+    if (engNotation) {
+        Text += misc::num2str(VarPos[ii],Precision) + "\n";
+    } else {
+        Text += QString::number(VarPos[ii],'g',Precision) + "\n";
+    }
   }
 
   Text += pGraph->Var + ": ";
@@ -230,7 +240,11 @@ void Marker::createText()
   } else {
       double mag = sqrt(pz[0]*pz[0] + pz[1]*pz[1]);
       double val = qucs::num2db(mag,ax->Units);
-      Text += QString::number(val,'g',Precision);
+      if (engNotation) {
+          Text += misc::num2str(val,Precision) + "\n";
+      } else {
+          Text += QString::number(val,'g',Precision);
+      }
   }
 
   assert(diag());
@@ -405,6 +419,20 @@ void Marker::paint(ViewPainter *p, int x0, int y0)
   fy2 = (float(y0)-fCY)*p->Scale + p->DY;
   p->Painter->drawLine(x1_, y1_, lround(fx2), lround(fy2));
 
+  if (indicatorMode == indicator_Square) {
+    p->Painter->drawRect(fx2 - (IND_SIZE / 2 * p->Scale), fy2 - (IND_SIZE / 2 * p->Scale), 
+                            IND_SIZE * p->Scale, IND_SIZE * p->Scale);
+  }
+  else if (indicatorMode == indicator_Triangle) {
+    // Creating a path in case a filled triangle is needed.
+    QPainterPath path;
+    path.moveTo(fx2, fy2);
+    path.lineTo(fx2 - (IND_SIZE / 2 * p->Scale), fy2 - (IND_SIZE * p->Scale));
+    path.lineTo(fx2 + (IND_SIZE / 2 * p->Scale), fy2 - (IND_SIZE * p->Scale));
+    path.lineTo(fx2, fy2);
+    p->Painter->drawPath(path);
+  }
+
   if(isSelected) {
     p->Painter->setPen(QPen(Qt::darkGray,3));
     p->drawRoundRect(x0+x1-3, y0+y1-3, x2+6, y2+6);
