@@ -47,7 +47,7 @@ private:
     Xyce *xyce;
 
 public:
-    explicit ExternSimDialog(Schematic *sch, QWidget *parent = 0,
+    explicit ExternSimDialog(Schematic *sch,
                              bool netlist_mode = false);
     ~ExternSimDialog();
 
@@ -57,6 +57,8 @@ public:
 private:
     void saveLog();
     void addLogEntry(const QString&text, const QIcon &icon);
+    bool logContainsError(const QString &out);
+    bool logContainsWarning(const QString &out);
     
 signals:
     void simulated(ExternSimDialog *);
