@@ -37,6 +37,23 @@
 #include <QtWidgets>
 
 
+QString misc::getWindowTitle()
+{
+    QString title = QUCS_NAME " " PACKAGE_VERSION;
+    if (title.endsWith(".0")) {
+        title.chop(2);
+    }
+#if defined(GIT)
+    QString hash = GIT;
+    if (!hash.isEmpty()) {
+        title = title + "-" + hash;
+    }
+#endif
+
+    return title;
+}
+
+
 bool misc::isDarkTheme()
 {
     QLabel *lbl = new QLabel("check dark");
@@ -217,10 +234,10 @@ void misc::str2num(const QString& s_, double& Number, QString& Unit, double& Fac
   }*/
 
   QRegularExpression Expr( QRegularExpression("[^0-9\\x2E\\x2D\\x2B]") );
-  int i = str.indexOf( Expr );
+  auto i = str.indexOf( Expr );
   if(i >= 0)
     if((str.at(i).toLatin1() | 0x20) == 'e') {
-      int j = str.indexOf( Expr , ++i);
+      auto j = str.indexOf( Expr , ++i);
       if(j == i)  j--;
       i = j;
     }
@@ -248,12 +265,10 @@ void misc::str2num(const QString& s_, double& Number, QString& Unit, double& Fac
   {
     Factor = 1.0;
   }
-
-  return;
 }
 
 // #########################################################################
-QString misc::num2str(double Num)
+QString misc::num2str(double Num, int Precision)
 {
   char c = 0;
   double cal = fabs(Num);
@@ -278,12 +293,31 @@ QString misc::num2str(double Num)
     if(c)  Num /= pow(10.0, double(3*Expo));
   }
 
-  QString Str = QString::number(Num);
+  QString Str;
+  if (Precision == -1) {
+      Str = QString::number(Num);
+  } else {
+      Str = QString::number(Num,'f',Precision);
+      qDebug() << Str;
+  }
+
   if(c)  Str += c;
 
   return Str;
 }
 
+QColor misc::ColorFromString(const QString& color)
+{
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+    return QColor::fromString(color);
+#else
+    QColor c;
+    c.setNamedColor(color);
+    return c;
+#endif
+
+}
+
 // #########################################################################
 void misc::convert2Unicode(QString& Text)
 {
