@@ -180,6 +180,8 @@ void Module::intoCategory (Module * m) {
 
 #define REGISTER_COMP_1(cat,val) \
   registerComponent (cat, &val::info)
+#define REGISTER_SPECIFIC_COMP_1(cat,val,inf1) \
+registerComponent (cat, &val::inf1)
 #define REGISTER_COMP_2(cat,val,inf1,inf2) \
   registerComponent (cat, &val::inf1); \
   registerComponent (cat, &val::inf2)
@@ -204,6 +206,10 @@ void Module::intoCategory (Module * m) {
   REGISTER_COMP_2 (QObject::tr("nonlinear components"),val,inf1,inf2)
 #define REGISTER_NONLINEAR_3(val,inf1,inf2,inf3) \
   REGISTER_COMP_3 (QObject::tr("nonlinear components"),val,inf1,inf2,inf3)
+#define REGISTER_MICROEL_1(val,inf1) \
+REGISTER_SPECIFIC_COMP_1 (QObject::tr("microelectronics"),val,inf1)
+#define REGISTER_MICROEL_2(val,inf1,inf2) \
+REGISTER_COMP_2 (QObject::tr("microelectronics"),val,inf1,inf2)
 #define REGISTER_VERILOGA_1(val) \
   REGISTER_COMP_1 (QObject::tr("verilog-a devices"),val)
 #define REGISTER_VERILOGA_2(val,inf1,inf2) \
@@ -231,7 +237,7 @@ void Module::intoCategory (Module * m) {
 #define REGISTER_SPICE_1(val) \
   REGISTER_COMP_1 (QObject::tr("SPICE components"),val)
 #define REGISTER_SPICE_SEC_1(val) \
-  REGISTER_COMP_1 (QObject::tr("SPICE specific sections"),val)
+  REGISTER_COMP_1 (QObject::tr("SPICE netlist sections"),val)
 #define REGISTER_SPICE_SIM_1(val) \
   REGISTER_COMP_1 (QObject::tr("SPICE simulations"),val)
 #define REGISTER_XSPICE_1(val) \
@@ -254,6 +260,7 @@ void Module::registerModules (void) {
   REGISTER_LUMPED_1 (Inductor);
   REGISTER_LUMPED_1 (IndQ);
   REGISTER_LUMPED_1 (CapQ);
+  REGISTER_LUMPED_1 (potentiometer);
   REGISTER_LUMPED_1 (Mutual);
   REGISTER_LUMPED_1 (Mutual2);
   REGISTER_LUMPED_1 (MutualX);
@@ -349,7 +356,6 @@ void Module::registerModules (void) {
       REGISTER_SOURCE_1 (vTRNOISE);
       REGISTER_SOURCE_1 (iTRNOISE);
       REGISTER_SOURCE_1 (vTRRANDOM);
-      REGISTER_SOURCE_1 (Vac_SPICE);
   //}
 
   // probes
@@ -405,15 +411,11 @@ void Module::registerModules (void) {
       REGISTER_NONLINEAR_1 (DIODE_SPICE);
       REGISTER_NONLINEAR_1 (NPN_SPICE);
       REGISTER_NONLINEAR_1 (PNP_SPICE);
-      REGISTER_NONLINEAR_2 (BJT_SPICE,infoNPN4,infoPNP4);
-      REGISTER_NONLINEAR_2 (BJT_SPICE,infoNPN5,infoPNP5);
+      REGISTER_NONLINEAR_2 (MOS_SPICE,info_NM3pin,info_PM3pin);
       REGISTER_NONLINEAR_1 (NJF_SPICE);
       REGISTER_NONLINEAR_1 (PJF_SPICE);
       REGISTER_NONLINEAR_1 (NMOS_SPICE);
       REGISTER_NONLINEAR_1 (PMOS_SPICE);
-      REGISTER_NONLINEAR_2 (MOS_SPICE,info_NM3pin,info_PM3pin);
-      REGISTER_NONLINEAR_2 (MOS_SPICE,info_NX3pin,info_PX3pin);
-      REGISTER_NONLINEAR_2 (MOS_SPICE,info_NX4pin,info_PX4pin);
       REGISTER_NONLINEAR_1 (MESFET_SPICE);
       REGISTER_NONLINEAR_1 (PMF_MESFET_SPICE);
       REGISTER_NONLINEAR_1 (S4Q_Ieqndef);
@@ -430,12 +432,22 @@ void Module::registerModules (void) {
       REGISTER_NONLINEAR_1 (TunnelDiode);
   //}
 
+// PDK devices
+      REGISTER_MICROEL_1 (R_SPICE, info_R3);
+      REGISTER_MICROEL_1 (C_SPICE, info_C3);
+      REGISTER_MICROEL_1 (DIODE_SPICE, info_DIODE3);
+      REGISTER_MICROEL_1 (NMOS_SPICE, info);
+      REGISTER_MICROEL_1 (PMOS_SPICE, info);
+      REGISTER_MICROEL_2 (MOS_SPICE,info_NM3pin,info_PM3pin);
+      REGISTER_MICROEL_2 (MOS_SPICE,info_NX3pin,info_PX3pin);
+      REGISTER_MICROEL_2 (MOS_SPICE,info_NX4pin,info_PX4pin);
+      REGISTER_MICROEL_2 (BJT_SPICE,infoNPN4,infoPNP4);
+      REGISTER_MICROEL_2 (BJT_SPICE,infoNPN5,infoPNP5);
 
   //if (QucsSettings.DefaultSimulator == spicecompat::simQucsator) {
       // verilog-a devices
       REGISTER_VERILOGA_1 (mod_amp);
       REGISTER_VERILOGA_1 (log_amp);
-      REGISTER_VERILOGA_1 (potentiometer);
       REGISTER_VERILOGA_1 (MESFET);
       REGISTER_VERILOGA_1 (photodiode);
       REGISTER_VERILOGA_1 (phototransistor);
