@@ -475,7 +475,7 @@ void QucsApp::initActions()
   connect(insPort, SIGNAL(toggled(bool)), SLOT(slotInsertPort(bool)));
 
   insWire = new QAction(QIcon(":bitmaps/svg/wire.svg"),	tr("Wire"), this);
-  insWire->setShortcut(tr("Ctrl+E"));
+  insWire->setShortcut(tr("Ctrl+W"));
   insWire->setStatusTip(tr("Inserts a wire"));
   insWire->setWhatsThis(tr("Wire\n\nInserts a wire"));
   insWire->setCheckable(true);
@@ -574,6 +574,19 @@ void QucsApp::initActions()
   setMarker->setCheckable(true);
   connect(setMarker, SIGNAL(toggled(bool)), SLOT(slotSetMarker(bool)));
 
+  setDiagramLimits = new QAction(QIcon((":/bitmaps/svg/viewwave.svg")),	tr("Set Diagram Limits"), this);
+  setDiagramLimits->setShortcut(tr("Ctrl+E"));
+  setDiagramLimits->setStatusTip(tr("Pick the diagram limits using the mouse. Right click for default."));
+  setDiagramLimits->setWhatsThis(tr("Set Diagram Limits\n\nPick the diagram limits using the mouse. Right click for default."));
+  setDiagramLimits->setCheckable(true);
+  connect(setDiagramLimits, SIGNAL(toggled(bool)), SLOT(slotSetDiagramLimits(bool)));
+
+  resetDiagramLimits = new QAction(tr("Reset Diagram Limits"), this);
+  resetDiagramLimits->setShortcut(tr("Ctrl+Shift+E"));
+  resetDiagramLimits->setStatusTip(tr("Resets the limits for all axis to auto."));
+  resetDiagramLimits->setWhatsThis(tr("Reset Diagram Limits\n\nResets the limits for all axis to auto."));
+  connect(resetDiagramLimits, SIGNAL(triggered()), SLOT(slotResetDiagramLimits()));
+
   showMsg = new QAction(tr("Show Last Messages"), this);
   showMsg->setShortcut(Qt::Key_F5);
   showMsg->setStatusTip(tr("Shows last simulation messages"));
@@ -787,6 +800,7 @@ void QucsApp::initMenuBar()
   viewMenu->addAction(magOne);
   viewMenu->addAction(magPlus);
   viewMenu->addAction(magMinus);
+  viewMenu->addAction(setDiagramLimits);
   viewMenu->addSeparator();
   //viewMenu->setCheckable(true);
   viewMenu->addAction(viewToolBar);
@@ -939,17 +953,21 @@ void QucsApp::initToolBar()
   simulateToolbar->addAction(tune);
   simulateToolbar->addAction(dpl_sch);
   simulateToolbar->addAction(setMarker);
+  simulateToolbar->addAction(setDiagramLimits);
 }
 
 // ----------------------------------------------------------
 void QucsApp::initStatusBar()
 {
+    DiagramValuesLabel = new QLabel("", statusBar());
+    statusBar()->addPermanentWidget(DiagramValuesLabel, 0);
+
   // To reserve enough space, insert the longest text and rewrite it afterwards.
-  SimulatorLabel = new QLabel(spicecompat::getDefaultSimulatorName(QucsSettings.DefaultSimulator));
-  statusBar()->addPermanentWidget(SimulatorLabel, 0);
+  //SimulatorLabel = new QLabel(spicecompat::getDefaultSimulatorName(QucsSettings.DefaultSimulator));
+  //statusBar()->addPermanentWidget(SimulatorLabel, 0);
 
   WarningLabel = new QLabel(tr("no warnings"), statusBar());
-  statusBar()->addPermanentWidget(WarningLabel, 0);
+  statusBar()->addWidget(WarningLabel, 0);
 
   PositionLabel = new QLabel("0 : 0", statusBar());
 #ifndef __APPLE__
@@ -995,10 +1013,12 @@ void QucsApp::slotResetWarnings()
 }
 
 // ----------------------------------------------------------
-void QucsApp::printCursorPosition(int x, int y)
+void QucsApp::printCursorPosition(int x, int y, QString text)
 {
   PositionLabel->setText(QString::number(x)+" : "+QString::number(y));
   PositionLabel->setMinimumWidth(PositionLabel->width());
+
+  DiagramValuesLabel->setText(text);
 }
 
 // --------------------------------------------------------------
