@@ -61,7 +61,7 @@ struct DigSignal {
   QString Type; // type of signal
 };
 typedef QMap<QString, DigSignal> DigMap;
-typedef enum {_NotRop, _Rect, _SelectionRect, _Line, _Ellipse, _Arc, _DotLine, _Translate, _Scale} PE;
+typedef enum {_NotRop, _Rect, _SelectionRect, _Line, _Ellipse, _Arc, _DotLine, _DotRect, _Translate, _Scale} PE;
 typedef struct {PE pe; int x1; int y1;int x2;int y2;int a; int b; bool PaintOnViewport;}PostedPaintEvent;
 
 // subcircuit, vhdl, etc. file structure
@@ -83,7 +83,7 @@ public:
 
   void setName(const QString&);
   void setChanged(bool, bool fillStack=false, char Op='*');
-  void paintGrid(ViewPainter*, int, int, int, int);
+  void drawGrid(const ViewPainter&);
   void print(QPrinter*, QPainter*, bool, bool);
 
   void paintSchToViewpainter(ViewPainter* p, bool printAll, bool toImage, int screenDpiX=96, int printerDpiX=300);
@@ -100,7 +100,27 @@ public:
   void  setOnGrid(int&, int&);
   bool  elementsOnGrid();
 
-  float zoom(float);
+  /**
+    Zoom around a "zooming center". Zooming center is a point on the canvas,
+    which doesn't move relative to a viewport while canvas is being zoomed in or
+    out.
+
+    This produces the effect of "concentrating" on a zooming center: with each
+    zoom-in step one would get closer and closer to the point, while point's
+    surroundings would go "out of sight", beyound the viewport's borders.
+
+    Zooming out works in backwards order: everything is like being "sucked into"
+    the zooming center.
+
+    If param \c viewportRelative is \c true then the given coordinates are
+    treated as relative to the viewport top-left corner. Otherwise they're
+    considered to be absolute i.e. relative to canvas top-left corner.
+
+    @param scaleChange       a multiplier for a current scale value
+    @param coords            coordinates of the "zooming center"
+    @param viewportRelative  tells if coordinates are absolute or relative to viewport
+  */
+  void zoomAroundPoint(double scaleChange, QPoint coords, bool viewportRelative);
   float zoomBy(float);
   void  showAll();
   void zoomToSelection();
@@ -123,10 +143,10 @@ public:
   bool    undo();
   bool    redo();
 
-  bool scrollUp(int);
-  bool scrollDown(int);
-  bool scrollLeft(int);
-  bool scrollRight(int);
+  void scrollUp(int);
+  void scrollDown(int);
+  void scrollLeft(int);
+  void scrollRight(int);
 
   bool checkDplAndDatNames();
 
@@ -143,11 +163,22 @@ public:
   QList<PostedPaintEvent>   PostedPaintEvents;
   bool symbolMode;  // true if in symbol painting mode
 
-
+  // Horizontal and vertical grid step
   int GridX, GridY;
-  int ViewX1, ViewY1, ViewX2, ViewY2;  // size of the document area
-  int UsedX1, UsedY1, UsedX2, UsedY2;  // document area used by elements
-  int zx1, zy1, zx2, zy2, dx, dy = 0;
+
+  // Variables View* are the coordinates of top-level and bottom-right corners
+  // of a rectangle representing the schematic "model". This
+  // rectangle may grow and shrink when user scrolls the view, and its
+  // coordinates change accordingly. Everything (elements, wires, etc.) lies
+  // inside this rectangle. The size of this rectangle is the "logical" size
+  // of the schematic. The comment in "renderModel" method describes how
+  // these variables ("model") is used to draw the scematic.
+  int ViewX1, ViewY1, ViewX2, ViewY2;
+
+  // Variables Used* hold the coordinates of top-left and bottom-right corners
+  // of a smallest rectangle which can fit all elements of the schematic.
+  // This rectangle exists in the same coordinate system as View*-rectangle
+  int UsedX1, UsedY1, UsedX2, UsedY2;
 
   int showFrame;
   QString Frame_Text0, Frame_Text1, Frame_Text2, Frame_Text3;
@@ -169,7 +200,7 @@ public:
   void setFileInfo(QString FileName) { FileInfo = QFileInfo(FileName); }
 
 signals:
-  void signalCursorPosChanged(int, int);
+  void signalCursorPosChanged(int, int, QString);
   void signalUndoState(bool);
   void signalRedoState(bool);
   void signalFileChanged(bool);
@@ -197,10 +228,119 @@ protected slots:
   void slotScrollRight();
 
 private:
+  // Viewport-realative coordinates of the cursor between mouse movements.
+  // Used in "pan with mouse" feature.
+  QPoint previousCursorPosition;
+
   bool dragIsOkay;
   /*! \brief hold system-independent information about a schematic file */
   QFileInfo FileInfo;
 
+  /**
+    Minimum scale at which schematic could be drawn.
+  */
+  static constexpr double minScale = 0.1;
+
+  /**
+    Maximum scale at which schematic could be drawn.
+  */
+  static constexpr double maxScale = 10.0;
+
+  /**
+    Returns a rectangle which describes the model plane of the schematic.
+    The rectangle is a copy, changes made to it do not affect schematic state.
+  */
+  QRect modelRect();
+
+  /**
+    Returns a rectangle which describes the viewport. Top-left corner is (0,0),
+    width and height are equal to viewport's width and height.
+  */
+  QRect viewportRect();
+
+  /**
+    Given a coordinates of viewport point returns coordinates of the model plane point
+    displayed at given location of the viewport.
+  */
+  QPoint viewportToModel(QPoint viewportCoordinates);
+
+  /**
+    Given coordinates of a point on the view plane (schematic's canvas), this method
+    returns coordinates of a corresponding point on the model plane.
+
+    @param viewCoordinates a point on the view plane
+    @return a corresponding point on the model plane
+  */
+  QPoint viewToModel(const QPoint& viewCoordinates);
+
+  /**
+    Given coordinates of a point on the model plane, this method returns coordinates
+    of a corresponding point on the view plane (schematic's canvas).
+
+    @param modelCoordinates a point on the model plane
+    @return a corresponding point on the view plane
+  */
+  QPoint modelToView(const QPoint& modelCoordinates);
+
+  /**
+    If given value violates lower or upper scale limit, then returns
+    the limit value, original value otherwise.
+  */
+  static double clipScale(double);
+
+  /**
+    Tells whether the model should be rerendered. Model should be rendered
+    if the given scale differs from the current one or if the point displayed
+    at \a viewportCoords in the viewport differs from the point \a modelCoords.
+    Otherwise there is no changes and no need to rerender.
+
+    @param scale desired scale
+    @param newModelBounds a rectangle describing the desired model bounds
+    @param modelCoords coordinates of a point on the model plane
+    @param viewportCoords coordinates of a point in the viewport.
+  */
+  bool shouldRender(const double& scale, const QRect& newModelBounds, const QPoint& modelCoords, const QPoint& viewportCoords);
+
+  /**
+    Renders schematic model on Q3ScrollView's contents at a given scale,
+    and positions the contents so that the point \a modelPlaneCoords of the
+    model is displayed at location \a viewportCoords of the viewport.
+
+    There is no need to call "update" on Q3ScrollView after using this method.
+    It is done as a part of rendering process.
+
+    @param  scale            desired new scale. It is clipped when exceeds
+                             a lower or upperlimit
+    @param  newModelBounds   a rectangle describing the desired model bounds
+    @param  modelPlaneCoords coordinates of a point somewhere within
+                             \a newModelBounds
+    @param  viewportCoords   coordinates of the point on the viewport where
+                             \a modelPlaneCoords should be placed after rendering
+    @return new scale value
+  */
+  double renderModel(double scale, QRect newModelBounds, QPoint modelPlaneCoords, QPoint viewportCoords);
+
+  /**
+    Render the model without changing its size and position the contents
+    so that the center of the model is displayed at center of the viewport.
+
+    @param scale desired new scale. It is clipped if exceeds bounds.
+    @return new scale value
+  */
+  double renderModel(double scale);
+
+  /**
+    Render the model without changing its size and position the contents so that
+    the point \a modelPlaneCoords of the model is displayed at location \a
+    viewportCoords of the viewport.
+
+    @param scale desired new scale. It is clipped if exceeds limits
+    @param modelPlaneCoords coordinates of the point on the model plane
+    @param viewportCoords coordinates of the point on the viewport
+    @return new scale value
+  */
+  double renderModel(double scale, QPoint modelPlaneCoords, QPoint viewportCoords);
+
 /* ********************************************************************
    *****  The following methods are in the file                   *****
    *****  "schematic_element.cpp". They only access the QPtrList  *****
@@ -252,7 +392,7 @@ public:
   Component* searchSelSubcircuit();
   Component* selectedComponent(int, int);
   void       deleteComp(Component*);
-  Component* getComponentByName(const QString& compname);
+  Component* getComponentByName(const QString& compname) const;
 
   void     oneLabel(Node*);
   int      placeNodeLabel(WireLabel*);
