@@ -285,8 +285,13 @@ int Schematic::savePropsJSON()
         if (line.contains("parameter")) {
             auto tokens = line.split(QRegularExpression("[\\s=;]"),qucs::SkipEmptyParts);
             if (tokens.count() >= 4) {
-               prop_name.append(tokens.at(2));
-               prop_val.append(tokens.at(3));
+                for(int ic = 0; ic <= tokens.count(); ic++) {
+                    if (tokens.at(ic) == "parameter") {
+                        prop_name.append(tokens.at(ic+2));
+                        prop_val.append(tokens.at(ic+3));
+                        break;
+                    }
+                }
             }
         }
     }
@@ -866,6 +871,8 @@ bool Schematic::loadPaintings(QTextStream *stream, Q3PtrList<Painting> *List)
   QString Line, cstr;
   while(!stream->atEnd()) {
     Line = stream->readLine();
+    if (Line.trimmed().isEmpty()) continue;
+
     if(Line.at(0) == '<') if(Line.at(1) == '/') return true;
 
     Line = Line.trimmed();
@@ -1451,16 +1458,19 @@ bool Schematic::throughAllComps(QTextStream *stream, int& countInit,
     }
 
     if (pc->Model == "SPfile" &&
-        QucsSettings.DefaultSimulator != spicecompat::simQucsator) {
+        QucsSettings.DefaultSimulator == spicecompat::simNgspice) {
         QString f = pc->getSubcircuitFile();
         QString sub_name = "Sub_" + pc->Model + "_" + pc->Name;
         S2Spice *conv = new S2Spice();
         conv->setFile(f);
         conv->setDeviceName(sub_name);
-        if (!conv->convertTouchstone(stream)) {
-            QMessageBox::warning(this,tr("Netlist error"),
-                                 conv->getErrText());
+        bool r = conv->convertTouchstone(stream);
+        QString msg = conv->getErrText();
+        if (!r) {
+            QMessageBox::warning(this,tr("Netlist error"), msg);
             return false;
+        } else if (!msg.isEmpty()) {
+            QMessageBox::warning(this,tr("S2Spice warning"), msg);
         }
         delete conv;
     }
@@ -1674,7 +1684,8 @@ void Schematic::createSubNetlistPlain(QTextStream *stream, QPlainTextEdit *ErrTe
             case 'o': // output ports need workaround
               Signals.insert(*it_name, DigSignal(*it_name, *it_type));
               (*it_name) = "net_out" + (*it_name);
-              // no "break;" here !!!
+              (*it_name) += " : " + pc->Props.at(1)->Value;
+              break;
             default:
               (*it_name) += " : " + pc->Props.at(1)->Value;
           }
