@@ -29,15 +29,6 @@ C_SPICE::C_SPICE()
     Description = QObject::tr("SPICE C:\nMultiple line ngspice or Xyce C specifications allowed using \"+\" continuation lines.\nLeave continuation lines blank when NOT in use.");
     Simulator = spicecompat::simSpice;
 
-    Lines.append(new qucs::Line( -4,-11, -4, 11,QPen(Qt::darkRed,3)));
-    Lines.append(new qucs::Line(  4,-11,  4, 11, QPen(Qt::darkRed,3)));
-    Lines.append(new qucs::Line(-30,  0, -4,  0,  QPen(Qt::darkBlue,2)));
-    Lines.append(new qucs::Line(  4,  0, 30,  0,   QPen(Qt::darkBlue,2)));
-    
-
-    Ports.append(new Port( 30,  0));
-    Ports.append(new Port(-30,  0));
-
     x1 = -30; y1 = -13;
     x2 =  30; y2 =  13;
 
@@ -52,10 +43,34 @@ C_SPICE::C_SPICE()
     Props.append(new Property("C_Line 3", "", false,"+ continuation line 2"));
     Props.append(new Property("C_Line 4", "", false,"+ continuation line 3"));
     Props.append(new Property("C_Line 5", "", false,"+ continuation line 4"));
+    Props.append(new Property("Pins", "2", true,"[2,3] Pins count"));
+    Props.append(new Property("Letter", "C", true,"[C,X,N] SPICE letter"));
 
-    rotate();  // fix historical flaw
+    createSymbol();
+
+    // rotate();  // fix historical flaw
 }
 
+void C_SPICE::createSymbol()
+{
+    int Npins = getProperty("Pins")->Value.toInt();
+    Lines.append(new qucs::Line( -4,-11, -4, 11,QPen(Qt::darkRed,3)));
+    Lines.append(new qucs::Line(  4,-11,  4, 11, QPen(Qt::darkRed,3)));
+    Lines.append(new qucs::Line(-30,  0, -4,  0,  QPen(Qt::darkBlue,2)));
+    Lines.append(new qucs::Line(  4,  0, 30,  0,   QPen(Qt::darkBlue,2)));
+
+    if (Npins >= 3) {
+        Lines.append(new qucs::Line(  0,  -15, 0,  -30,QPen(Qt::darkRed,2)));
+    }
+
+    Ports.append(new Port( 30,  0));
+    Ports.append(new Port(-30,  0));
+
+    if (Npins >= 3) Ports.append(new Port( 0, -30));
+
+}
+
+
 C_SPICE::~C_SPICE()
 {
 }
@@ -74,6 +89,20 @@ Element* C_SPICE::info(QString& Name, char* &BitmapFile, bool getNewOne)
   return 0;
 }
 
+Element* C_SPICE::info_C3(QString& Name, char* &BitmapFile, bool getNewOne)
+{
+  Name = QObject::tr("C Capacitor 3 pin");
+  BitmapFile = (char *) "C_SPICE";
+
+  if(getNewOne)  {
+      auto p = new C_SPICE();
+      p->Props.at(5)->Value = "3";
+      p->recreate(0);
+      return p;
+  }
+  return 0;
+}
+
 QString C_SPICE::netlist()
 {
     return QString("");
@@ -81,7 +110,8 @@ QString C_SPICE::netlist()
 
 QString C_SPICE::spice_netlist(bool)
 {
-    QString s = spicecompat::check_refdes(Name,SpiceModel);
+    QString ltr = getProperty("Letter")->Value;
+    QString s = spicecompat::check_refdes(Name,ltr);
     for (Port *p1 : Ports) {
         QString nam = p1->Connection->Name;
         if (nam=="gnd") nam = "0";
