@@ -29,20 +29,6 @@ DIODE_SPICE::DIODE_SPICE()
     Description = QObject::tr("SPICE D:\nMultiple line ngspice or Xyce D model specifications allowed using \"+\" continuation lines.\nLeave continuation lines blank when NOT in use.");
     Simulator = spicecompat::simSpice;
 
-    Lines.append(new qucs::Line(-30,  0, -20,  0,QPen(Qt::darkBlue,3)));
-    Lines.append(new qucs::Line( -20, 0, -6,   0,QPen(Qt::darkRed,3)));
-    Lines.append(new qucs::Line(  6,  0, 20,   0,QPen(Qt::darkRed,3)));
-    Lines.append(new qucs::Line( 20,  0, 30,   0,QPen(Qt::darkBlue,3)));
- 
- 
-    Lines.append(new qucs::Line( -6, -9, -6,  9,QPen(Qt::darkRed,3)));
-    Lines.append(new qucs::Line(  6, -9,  6,  9,QPen(Qt::darkRed,3)));
-    Lines.append(new qucs::Line( -6, -9,  6,  0,QPen(Qt::darkRed,3)));
-    Lines.append(new qucs::Line( -6,  9,  6,  0,QPen(Qt::darkRed,3)));
-
-  Ports.append(new Port(-30, 0));
-  Ports.append(new Port( 30, 0));
-
   x1 = -30; y1 = -11;
   x2 =  30; y2 =  11;
 
@@ -58,6 +44,34 @@ DIODE_SPICE::DIODE_SPICE()
     Props.append(new Property("D_Line 3", "", false,"+ continuation line 2"));
     Props.append(new Property("D_Line 4", "", false,"+ continuation line 3"));
     Props.append(new Property("D_Line 5", "", false,"+ continuation line 4"));
+    Props.append(new Property("Pins", "2", true,"[2,3] Pins count"));
+    Props.append(new Property("Letter", "D", true,"[D,X,N] SPICE letter"));
+
+    createSymbol();
+}
+
+void DIODE_SPICE::createSymbol()
+{
+    int Npins = getProperty("Pins")->Value.toInt();
+    Lines.append(new qucs::Line(-30,  0, -20,  0,QPen(Qt::darkBlue,3)));
+    Lines.append(new qucs::Line( -20, 0, -6,   0,QPen(Qt::darkRed,3)));
+    Lines.append(new qucs::Line(  6,  0, 20,   0,QPen(Qt::darkRed,3)));
+    Lines.append(new qucs::Line( 20,  0, 30,   0,QPen(Qt::darkBlue,3)));
+
+
+    Lines.append(new qucs::Line( -6, -9, -6,  9,QPen(Qt::darkRed,3)));
+    Lines.append(new qucs::Line(  6, -9,  6,  9,QPen(Qt::darkRed,3)));
+    Lines.append(new qucs::Line( -6, -9,  6,  0,QPen(Qt::darkRed,3)));
+    Lines.append(new qucs::Line( -6,  9,  6,  0,QPen(Qt::darkRed,3)));
+
+    if (Npins >= 3) {
+        Lines.append(new qucs::Line(  0,  -5, 0,  -30,QPen(Qt::darkRed,2)));
+    }
+
+    Ports.append(new Port(-30, 0));
+    Ports.append(new Port( 30, 0));
+
+    if (Npins >= 3) Ports.append(new Port( 0, -30));
 
 }
 
@@ -79,6 +93,20 @@ Element* DIODE_SPICE::info(QString& Name, char* &BitmapFile, bool getNewOne)
   return 0;
 }
 
+Element* DIODE_SPICE::info_DIODE3(QString& Name, char* &BitmapFile, bool getNewOne)
+{
+  Name = QObject::tr("D Diode 3 pin");
+  BitmapFile = (char *) "DIODE_SPICE";
+
+  if(getNewOne)  {
+      auto p = new DIODE_SPICE();
+      p->Props.at(5)->Value = "3";
+      p->recreate(0);
+      return p;
+  }
+  return 0;
+}
+
 QString DIODE_SPICE::netlist()
 {
     return QString("");
@@ -86,7 +114,8 @@ QString DIODE_SPICE::netlist()
 
 QString DIODE_SPICE::spice_netlist(bool)
 {
-    QString s = spicecompat::check_refdes(Name,SpiceModel);
+    QString ltr = getProperty("Letter")->Value;
+    QString s = spicecompat::check_refdes(Name,ltr);
     for (Port *p1 : Ports) {
         QString nam = p1->Connection->Name;
         if (nam=="gnd") nam = "0";
