@@ -23,22 +23,11 @@
 #include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
-
 R_SPICE::R_SPICE()
 {
     Description = QObject::tr("SPICE R:\nMultiple line ngspice or Xyce R specifications allowed using \"+\" continuation lines.\nLeave continuation lines blank when NOT in use.  ");
     Simulator = spicecompat::simSpice;
 
-    Lines.append(new qucs::Line(-18, -9, 18, -9,QPen(Qt::darkRed,3)));
-    Lines.append(new qucs::Line( 18, -9, 18,  9,QPen(Qt::darkRed,3)));
-    Lines.append(new qucs::Line( 18,  9,-18,  9,QPen(Qt::darkRed,3)));
-    Lines.append(new qucs::Line(-18,  9,-18, -9,QPen(Qt::darkRed,3)));
-    Lines.append(new qucs::Line(-30,  0,-18,  0,QPen(Qt::darkBlue,2)));
-    Lines.append(new qucs::Line( 18,  0, 30,  0,QPen(Qt::darkBlue,2)));
-    
-    Ports.append(new Port(-30,  0));
-    Ports.append(new Port( 30,  0));
-
     x1 = -30; y1 = -11;
     x2 =  30; y2 =  11;
 
@@ -54,10 +43,34 @@ R_SPICE::R_SPICE()
     Props.append(new Property("R_Line 3", "", false,"+ continuation line 2"));
     Props.append(new Property("R_Line 4", "", false,"+ continuation line 3"));
     Props.append(new Property("R_Line 5", "", false,"+ continuation line 4"));
+    Props.append(new Property("Pins", "2", true,"[2,3] Pins count"));
+    Props.append(new Property("Letter", "R", true,"[R,X,N] SPICE letter"));
 
+    createSymbol();
 
+    // rotate();  // fix historical flaw
+
+}
+
+void R_SPICE::createSymbol()
+{
+    int Npins = getProperty("Pins")->Value.toInt();
+    Lines.append(new qucs::Line(-18, -9, 18, -9,QPen(Qt::darkRed,3)));
+    Lines.append(new qucs::Line( 18, -9, 18,  9,QPen(Qt::darkRed,3)));
+    Lines.append(new qucs::Line( 18,  9,-18,  9,QPen(Qt::darkRed,3)));
+    Lines.append(new qucs::Line(-18,  9,-18, -9,QPen(Qt::darkRed,3)));
+    Lines.append(new qucs::Line(-30,  0,-18,  0,QPen(Qt::darkBlue,2)));
+    Lines.append(new qucs::Line( 18,  0, 30,  0,QPen(Qt::darkBlue,2)));
+
+    if (Npins >= 3) {
+        Lines.append(new qucs::Line(  0,  -10, 0,  -30,QPen(Qt::darkRed,2)));
+    }
+
+    Ports.append(new Port(-30,  0));
+    Ports.append(new Port( 30,  0));
+
+    if (Npins >= 3) Ports.append(new Port( 0, -30));
 
-    rotate();  // fix historical flaw
 }
 
 R_SPICE::~R_SPICE()
@@ -66,7 +79,7 @@ R_SPICE::~R_SPICE()
 
 Component* R_SPICE::newOne()
 {
-  return new R_SPICE();
+    return new R_SPICE();
 }
 
 Element* R_SPICE::info(QString& Name, char* &BitmapFile, bool getNewOne)
@@ -78,6 +91,20 @@ Element* R_SPICE::info(QString& Name, char* &BitmapFile, bool getNewOne)
   return 0;
 }
 
+Element* R_SPICE::info_R3(QString& Name, char* &BitmapFile, bool getNewOne)
+{
+  Name = QObject::tr("R Resistor 3 pin");
+  BitmapFile = (char *) "R_SPICE";
+
+  if(getNewOne)  {
+      auto p = new R_SPICE();
+      p->Props.at(5)->Value = "3";
+      p->recreate(0);
+      return p;
+  }
+  return 0;
+}
+
 QString R_SPICE::netlist()
 {
     return QString("");
@@ -85,11 +112,12 @@ QString R_SPICE::netlist()
 
 QString R_SPICE::spice_netlist(bool)
 {
-    QString s = spicecompat::check_refdes(Name,SpiceModel);
+    QString ltr = getProperty("Letter")->Value;
+    QString s = spicecompat::check_refdes(Name,ltr);
     for (Port *p1 : Ports) {
         QString nam = p1->Connection->Name;
         if (nam=="gnd") nam = "0";
-        s += " "+ nam+" ";   // node names
+        s += " " + nam + " ";   // node names
     }
 
     QString R= Props.at(0)->Value;
