@@ -78,5 +78,7 @@ Element* InclScript::info(QString& Name, char* &BitmapFile, bool getNewOne)
 
 QString InclScript::getExpression(bool)
 {
+    if (isActive != Component::isActive)
+        return QString("");
     return Props.at(0)->Value+"\n";
 }
